import { ComponentRendering, Field, HtmlElementRendering, Item, RouteData } from '@sitecore-jss/sitecore-jss/layout';
import { Component, VNode, DefineComponent } from 'vue';
import { ComponentFactory } from './sharedTypes';
export interface PlaceholderProps {
    [key: string]: any;
    /** Name of the placeholder to render. */
    name: string;
    /** Rendering data to be used when rendering the placeholder. */
    rendering: ComponentRendering | RouteData;
    /**
     * A factory function that will receive a componentName and return an instance of a React component.
     * When rendered within a <SitecoreContext> component, defaults to the context componentFactory.
     */
    componentFactory?: ComponentFactory;
    /**
     * An object of field names/values that are aggregated and propagated through the component tree created by a placeholder.
     * Any component or placeholder rendered by a placeholder will have access to this data via `props.fields`.
     */
    fields?: {
        [name: string]: Field | Item[];
    };
    /**
     * An object of rendering parameter names/values that are aggregated and propagated through the component tree created by a placeholder.
     * Any component or placeholder rendered by a placeholder will have access to this data via `props.params`.
     */
    params?: {
        [name: string]: string;
    };
    /**
     * A component that is rendered in place of any components that are in this placeholder,
     * but do not have a definition in the componentFactory (i.e. don't have a React implementation)
     */
    missingComponentComponent?: DefineComponent;
    /**
     * A component that is rendered in place of any components that are hidden.
     */
    hiddenRenderingComponent?: DefineComponent;
    /**
     * A component that is rendered in place of the placeholder when an error occurs rendering
     * the placeholder
     */
    errorComponent?: DefineComponent;
}
export type JssDynamicComponent = Component & {
    isxEditorComponent?: boolean;
};
export declare const getPlaceholderDataFromRenderingData: (rendering: ComponentRendering | RouteData, name: string) => (ComponentRendering<import("@sitecore-jss/sitecore-jss/layout").ComponentFields> | HtmlElementRendering)[];
/**
 * Gets Vue elements (VNodes) from placeholder data, using componentFactory to resolve component definitions
 * and createVueElement to create VNodes for use in a Vue `render` function. Note: you can't use VNodes in
 * component templates. You'll need to convert the VNodes to "renderable" components, a.k.a. dynamic components.
 * @see convertVNodesToDynamicComponents or @see getDynamicComponentsFromRenderingData for options.
 * @param {Array<ComponentRendering | HtmlElementRendering>} placeholderData
 * @param {PlaceholderProps} placeholderProps
 * @param {ComponentFactory} [componentFactory]
 * @returns {VNode[]} vnodes
 */
export declare function getVNodesForRenderingData(placeholderData: Array<ComponentRendering | HtmlElementRendering>, placeholderProps: PlaceholderProps, componentFactory?: ComponentFactory): VNode<import("@vue/runtime-core").RendererNode, import("@vue/runtime-core").RendererElement, {
    [key: string]: any;
}>[];
/**
 * Convenience method that calls {@link getVNodesForRenderingData} and {@link convertVNodesToDynamicComponents}
 * to return "renderable" components, i.e. components that can be rendered in a Vue template, a.k.a. dynamic components.
 * @param {Array<ComponentRendering | HtmlElementRendering>} placeholderData
 * @param {PlaceholderProps} placeholderProps
 * @param {ComponentFactory} componentFactory
 * @returns {JssDynamicComponent[]} dynamic components
 */
export declare function getDynamicComponentsFromRenderingData(placeholderData: Array<ComponentRendering | HtmlElementRendering>, placeholderProps: PlaceholderProps, componentFactory?: ComponentFactory): JssDynamicComponent[];
/**
 * Converts VNodes to components that render the vnode.
 * Also evaluates VNodes to determine if they are Experience Editor components/elements and if so,
 * adds an identifying property to the component.
 * @param {VNode[]} vnodes
 * @returns {JssDynamicComponent[]} dynamic components
 */
export declare function convertVNodesToDynamicComponents(vnodes: VNode[]): JssDynamicComponent[];
